==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/memquota/QuotaFluent.java <==
package me.snowdrop.istio.mixer.adapter.memquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface QuotaFluent<A extends QuotaFluent<A>> extends Fluent<A>{


    public Long getMaxAmount();
    public A withMaxAmount(Long maxAmount);
    public Boolean hasMaxAmount();
    public A withNewMaxAmount(String arg1);
    public A withNewMaxAmount(long arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A addToOverrides(int index,me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public A setToOverrides(int index,me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public A addToOverrides(me.snowdrop.istio.mixer.adapter.memquota.Override... items);
    public A addAllToOverrides(Collection<me.snowdrop.istio.mixer.adapter.memquota.Override> items);
    public A removeFromOverrides(me.snowdrop.istio.mixer.adapter.memquota.Override... items);
    public A removeAllFromOverrides(Collection<me.snowdrop.istio.mixer.adapter.memquota.Override> items);
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.memquota.Override> getOverrides();
    public List<me.snowdrop.istio.mixer.adapter.memquota.Override> buildOverrides();
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildOverride(int index);
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildFirstOverride();
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildLastOverride();
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<OverrideBuilder> predicate);
    public A withOverrides(List<me.snowdrop.istio.mixer.adapter.memquota.Override> overrides);
    public A withOverrides(me.snowdrop.istio.mixer.adapter.memquota.Override... overrides);
    public Boolean hasOverrides();
    public QuotaFluent.OverridesNested<A> addNewOverride();
    public QuotaFluent.OverridesNested<A> addNewOverrideLike(me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public QuotaFluent.OverridesNested<A> setNewOverrideLike(int index,me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public QuotaFluent.OverridesNested<A> editOverride(int index);
    public QuotaFluent.OverridesNested<A> editFirstOverride();
    public QuotaFluent.OverridesNested<A> editLastOverride();
    public QuotaFluent.OverridesNested<A> editMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<OverrideBuilder> predicate);
    public Long getValidDuration();
    public A withValidDuration(Long validDuration);
    public Boolean hasValidDuration();
    public A withNewValidDuration(String arg1);
    public A withNewValidDuration(long arg1);

    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OverrideFluent<QuotaFluent.OverridesNested<N>>{

        
    public N and();    public N endOverride();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/memquota/QuotaFluent.java <==
package me.snowdrop.istio.mixer.adapter.memquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface QuotaFluent<A extends QuotaFluent<A>> extends Fluent<A>{


    public Integer getMaxAmount();
    public A withMaxAmount(Integer maxAmount);
    public Boolean hasMaxAmount();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public A addToOverrides(int index,me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public A setToOverrides(int index,me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public A addToOverrides(me.snowdrop.istio.mixer.adapter.memquota.Override... items);
    public A addAllToOverrides(Collection<me.snowdrop.istio.mixer.adapter.memquota.Override> items);
    public A removeFromOverrides(me.snowdrop.istio.mixer.adapter.memquota.Override... items);
    public A removeAllFromOverrides(Collection<me.snowdrop.istio.mixer.adapter.memquota.Override> items);
    public A removeMatchingFromOverrides(io.fabric8.kubernetes.api.builder.Predicate<OverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.adapter.memquota.Override> getOverrides();
    public List<me.snowdrop.istio.mixer.adapter.memquota.Override> buildOverrides();
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildOverride(int index);
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildFirstOverride();
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildLastOverride();
    public me.snowdrop.istio.mixer.adapter.memquota.Override buildMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<OverrideBuilder> predicate);
    public Boolean hasMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<OverrideBuilder> predicate);
    public A withOverrides(List<me.snowdrop.istio.mixer.adapter.memquota.Override> overrides);
    public A withOverrides(me.snowdrop.istio.mixer.adapter.memquota.Override... overrides);
    public Boolean hasOverrides();
    public QuotaFluent.OverridesNested<A> addNewOverride();
    public QuotaFluent.OverridesNested<A> addNewOverrideLike(me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public QuotaFluent.OverridesNested<A> setNewOverrideLike(int index,me.snowdrop.istio.mixer.adapter.memquota.Override item);
    public QuotaFluent.OverridesNested<A> editOverride(int index);
    public QuotaFluent.OverridesNested<A> editFirstOverride();
    public QuotaFluent.OverridesNested<A> editLastOverride();
    public QuotaFluent.OverridesNested<A> editMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<OverrideBuilder> predicate);
    public Integer getValidDuration();
    public A withValidDuration(Integer validDuration);
    public Boolean hasValidDuration();

    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OverrideFluent<QuotaFluent.OverridesNested<N>>{

        
    public N and();    public N endOverride();
}


}
